@@ -1813,6 +1813,29 @@ static void DNDBeginCB(
 		}
 }
 
+/*
+ *      DND "drag_failed" handler, this is called when a drag and drop has
+ *      failed (e.g., by pressing ESC).
+ */
+static gboolean DNDFailedCB(
+        GtkWidget *widget, GdkDragContext *context, GtkDragResult result)
+{
+(void)widget;
+(void)context;
+(void)result;
+
+GLOBALS->dnd_state = 0;
+GLOBALS->tree_dnd_begin = VIEW_DRAG_INACTIVE;
+GLOBALS->tree_dnd_requested = 0;
+
+MaxSignalLength();
+signalarea_configure_event(GLOBALS->signalarea, NULL);
+wavearea_configure_event(GLOBALS->wavearea, NULL);
+
+return(FALSE);
+}
+
+
 /*
  *      DND "drag_end" handler, this is called when a drag and drop has
  *	completed. So this function is the last one to be called in
@@ -2316,6 +2339,7 @@ void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 	                gtkwave_signal_connect(GTK_OBJECT(src), "drag_end", GTK_SIGNAL_FUNC(DNDEndCB), win);
 	                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_get", GTK_SIGNAL_FUNC(DNDDataRequestCB), win);
 	                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_delete", GTK_SIGNAL_FUNC(DNDDataDeleteCB), win);
+			gtkwave_signal_connect(GTK_OBJECT(src), "drag_failed", GTK_SIGNAL_FUNC(DNDFailedCB), win);
 			}
 
                 if(enable_receive) gtkwave_signal_connect(GTK_OBJECT(w),   "drag_data_received", GTK_SIGNAL_FUNC(DNDDataReceivedCB), win);
